@@ -131,9 +131,9 @@ on_pagina_base1_activate               (GtkMenuItem     *menuitem,
 	".SH SYNOPSIS\n.B <program>\n.RI [ options ]\n.br\n\n"
 	".SH DESCRIPTION\nThis manual page explains the \\fB<program>\\fP program."
 	" The \\fB<program>\\fP program is for...\n\n"
-	".SH OPTIONS\n.IP \\fB-OPTION\\fP\nThis option...\n\n"
+	".SH OPTIONS\n.IP \\fB\\-OPTION\\fP\nThis option...\n\n"
 	".SH NOTES\n\n"
-	".SH SEE ALSO\n");
+	".SH \"SEE ALSO\"\n");
 
 	insert_label(base,"Page created.");
 }
@@ -222,7 +222,10 @@ void
 on_sair4_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	g_signal_emit_by_name (G_OBJECT (wprincipal), "delete_event");
+	if (exit_dialog==NULL)
+		exit_dialog=create_exit_dialog();
+
+	gtk_widget_show(exit_dialog);
 }
 
 static void save_as(gchar *name)
@@ -342,7 +345,7 @@ void
 on_valores_retornados1_activate        (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	const gchar *base=_(".SH RETURN VALUE\n");
+	const gchar *base=_(".SH \"RETURN VALUE\"\n");
 
  	insert_label(base,"Section return value written.");
 }
@@ -352,7 +355,7 @@ void
 on_estados_de_saida1_activate          (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	const gchar *base=_(".SH EXIT STATUS\n");
+	const gchar *base=_(".SH \"EXIT STATUS\"\n");
  	insert_label(base,"Section exit status written.");
 }
 
@@ -426,7 +429,7 @@ void
 on_ver_tamen1_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	const gchar *base=_(".SH SEE ALSO\n");
+	const gchar *base=_(".SH \"SEE ALSO\"\n");
  	insert_label(base,"Section see also written.");
 }
 
@@ -435,7 +438,7 @@ void
 on_conforme_a1_activate                (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	const gchar *base=_(".SH CONFORMING TO\n");
+	const gchar *base=_(".SH \"CONFORMING TO\"\n");
  	insert_label(base,"Section conforming to written.");
 }
 
@@ -452,7 +455,7 @@ void
 on_otro1_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	const gchar *base=_(".SH <SECTION NAME>\n");
+	const gchar *base=_(".SH \"<SECTION NAME>\"\n");
  	insert_label(base,"Section other written.");
 }
 
@@ -614,7 +617,7 @@ void
 on_subcabeceira1_activate              (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	const gchar *base=_(".SS <NAME>\n");
+	const gchar *base=_(".SS \"<NAME>\"\n");
  	insert_label(base,"Subheader inserted.");
 }
 
@@ -645,16 +648,9 @@ on_paxina_creada1_activate             (GtkMenuItem     *menuitem,
 	datos=ReadConfFromFile("COMMAND");
 
 	if (datos==NULL)
-	{
-		strcpy(command,"xterm -e man -l ");
-		strcat(command,temp);
-	}
+		snprintf(command, sizeof command, "xterm -e man -l %s", temp);
 	else
-	{
-		strcpy(command,datos);
-		strcat(command," -l ");
-		strcat(command,temp);
-	}	
+		snprintf(command, sizeof command, "%s -l %s", datos, temp);
 
 	text=lookup_widget(wprincipal,"text");
 	
@@ -701,25 +697,31 @@ on_opcions_programa1_activate        (GtkMenuItem     *menuitem,
 	gchar datos[255];
 	
 	prefs=create_wpreferences();
-	
-/* Window Options with last options */
-/* First: command to view man pages */
 	aux=ReadConfFromFile("COMMAND");
 	if (aux != NULL)
 	{
-		strcpy(datos,aux);
+		strncpy(datos,aux, sizeof datos - 1);
+		datos[sizeof(datos) - 1] = 0;
 		obj=lookup_widget(GTK_WIDGET(prefs),"entry_command");
 		gtk_entry_set_text(GTK_ENTRY(obj),datos);
 	}
-/* Second: Internet Browser selector */
 	aux=ReadConfFromFile("INTERNET_BROWSER");
 	if (aux != NULL)
 	{
-		strcpy(datos,aux);
+		strncpy(datos,aux, sizeof(datos) - 1);
+		datos[sizeof(datos) - 1] = 0;
 		obj=lookup_widget(GTK_WIDGET(prefs),"combo2");
-		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(obj)->child),datos);
+		if (!strcmp(datos, "mozilla"))
+			 gtk_combo_box_set_active (GTK_COMBO_BOX(obj), 0);
+		else if (!strcmp(datos, "firefox"))
+			 gtk_combo_box_set_active (GTK_COMBO_BOX(obj), 1);
+		else if (!strcmp(datos, "galeon"))
+			 gtk_combo_box_set_active (GTK_COMBO_BOX(obj), 2);
+		else if (!strcmp(datos, "epiphany"))
+			 gtk_combo_box_set_active (GTK_COMBO_BOX(obj), 3);
+		else if (!strcmp(datos, "konqueror"))
+			 gtk_combo_box_set_active (GTK_COMBO_BOX(obj), 4);
 	}
-
 	gtk_widget_show(prefs);
 }
 
@@ -820,34 +822,26 @@ on_bpok_clicked                        (GtkButton       *button,
 	FILE *p;
 	GtkWidget *entry,*ch;
 	const gchar *entry_text=NULL;
-	gchar cad[256],cad2[50];
-	gchar *home, *browser;
+	gchar buf[1024];
+	gchar *rcname, *browser;
 
-/* I get home directory */
-	home=(gchar *)getenv("HOME");
-	strcpy(cad2,home);
-	strcat(cad2,"/.gmaneditrc");
+	rcname = g_build_filename (g_get_home_dir(), G_DIR_SEPARATOR_S, ".gmaneditrc", NULL );
 
 	entry=lookup_widget(prefs,"entry_command");
 	entry_text=gtk_entry_get_text(GTK_ENTRY(entry));
-	strcpy(cad,"# File created by gmanedit preferences option\n\nCOMMAND=");
-	strcat(cad,entry_text);
-	strcat(cad,"\n");
-	
 	ch = lookup_widget(prefs, "combo2");
-	browser = gtk_editable_get_chars
-		(GTK_EDITABLE (GTK_BIN(ch)->child), 0, -1);
-	strcat(cad,"INTERNET_BROWSER=");
-	strcat(cad,browser);
+	browser = gtk_combo_box_get_active_text (GTK_COMBO_BOX (ch));
+	snprintf(buf, sizeof buf, "# File created by gmanedit preferences option\n\nCOMMAND=%s\nINTERNET_BROWSER=%s", entry_text, browser);
 	g_free(browser);
 	
-	if ((p=fopen(cad2,"w"))!=NULL)
+	if ((p=fopen(rcname,"w"))!=NULL)
 	{
-		fprintf(p,"%s\n",cad);
+		fprintf(p,"%s\n",buf);
 		fclose(p);	
 	}
 	else
 		mensaje(strerror(errno),GTK_MESSAGE_ERROR);
+	g_free (rcname);
 	gtk_widget_destroy(prefs);
 }
 
@@ -862,30 +856,24 @@ on_bpcancel_clicked                    (GtkButton       *button,
 static gchar *ReadConfFromFile(gchar *variable)
 {
   FILE *f;
-  gchar readed[100];
-  gchar *home;
+  gchar *rcname;
   gchar *tok;
+  gchar buf[1024];
   
-// Intento de abrir el fichero con la configuracin personalizada  
-  home = getenv("HOME");
-  strcpy(readed,home);
-  strcat(readed,"/.gmaneditrc");
-  
-  f = fopen(readed,"r");
-  if (f == NULL)
-  {
-  	return((gchar *)NULL);
-  }  
+  rcname = g_build_filename (g_get_home_dir(), G_DIR_SEPARATOR_S, ".gmaneditrc", NULL );
+  f = fopen(rcname,"r");
+  g_free (rcname);
+
+  if (f == NULL) return((gchar *)NULL);
     
-  while (fgets(readed,80,f) != NULL)
+  while (fgets(buf,80,f) != NULL)
   {
-// Lo siguiente quita los retornos de carro de las lneas leidas
-     if (readed[strlen(readed)-1] == '\n')
-     	readed[strlen(readed)-1] = '\0';
+     if (buf[strlen(buf)-1] == '\n')
+     	buf[strlen(buf)-1] = '\0';
        
-     if ((readed[0] != '#') && (!strncmp(variable,readed,strlen(variable))))
+     if ((buf[0] != '#') && (!strncmp(variable,buf,strlen(variable))))
      {
-        tok = strtok(readed,"=");
+        tok = strtok(buf,"=");
         tok = strtok(NULL,"=");
         fclose(f);
         return(tok);
@@ -942,6 +930,7 @@ on_assistant_cancel                    (GtkAssistant *assistant,
                                         gpointer         user_data)
 {
 	gtk_widget_destroy (GTK_WIDGET(assistant));
+	wizard = NULL;
 }
 
 
@@ -1027,13 +1016,13 @@ on_dthe_end_finish                     (GtkAssistant *assistant,
 /* Section EXIT STATUS */
    ch = lookup_widget (GTK_WIDGET (assistant), "chexitstatus");
    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(ch))==TRUE)
-	strcat(cadena,_(".SH EXIT STATUS\n\n"));   
+	strcat(cadena,_(".SH \"EXIT STATUS\"\n\n"));   
 
 
 /* Section RETURN VALUE */
    ch = lookup_widget (GTK_WIDGET (assistant), "chreturnvalues");
    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(ch))==TRUE)
-	strcat(cadena,".SH RETURN VALUE\n\n");   
+	strcat(cadena,".SH \"RETURN VALUE\"\n\n");   
 /* Section ERRORS */
    ch = lookup_widget (GTK_WIDGET (assistant), "cherrors");
    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(ch))==TRUE)
@@ -1054,7 +1043,7 @@ on_dthe_end_finish                     (GtkAssistant *assistant,
 /* Section CONFORMING TO */
    ch = lookup_widget (GTK_WIDGET (assistant), "chconformingto");
    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(ch))==TRUE)
-	strcat(cadena,_(".SH CONFORMING TO\n\n"));   
+	strcat(cadena,_(".SH \"CONFORMING TO\"\n\n"));   
 /* Section NOTES */
    ch = lookup_widget (GTK_WIDGET (assistant), "chnotes");
    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(ch))==TRUE)
@@ -1070,7 +1059,7 @@ on_dthe_end_finish                     (GtkAssistant *assistant,
 /* Section SEE ALSO */
    ch = lookup_widget (GTK_WIDGET (assistant), "chseealso");
    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(ch))==TRUE)
-	strcat(cadena,_(".SH SEE ALSO\n\n"));   
+	strcat(cadena,_(".SH \"SEE ALSO\"\n\n"));   
 	
 /* Hide wizard */
    gtk_widget_hide(wizard);
@@ -1103,39 +1092,31 @@ on_home_page1_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
 	gchar *browser;
-	gchar cad[512];
+	gchar buf[1024];
 	gint exitstatus;
 	
 	browser=ReadConfFromFile("INTERNET_BROWSER");
 	if (browser==NULL)
 		browser="mozilla";
-	strcpy(cad, browser);
-	strcat(cad, " http://sourceforge.net/projects/gmanedit2");
+	snprintf(buf, sizeof buf, "%s http://sourceforge.net/projects/gmanedit2", browser);
 
-	g_spawn_command_line_sync(cad, NULL, NULL, &exitstatus, NULL);
+	g_spawn_command_line_sync(buf, NULL, NULL, &exitstatus, NULL);
 }
 
 static void help_without_gnome(GtkWidget *wid)
 {
 	GtkWidget *statusbar;
 	gchar *datos;
-	gchar temp[10],command[75];
+	gchar temp[10],command[1024];
 	gint exitstatus;
 
-// I read conf file ~/.gmaneditrc
 	strcpy(temp," 7 man");
 	datos=ReadConfFromFile("COMMAND");
 
 	if (datos==NULL)
-	{
-		strcpy(command,"xterm -e man");
-		strcat(command,temp);
-	}
+		snprintf(command, sizeof command, "xterm -e man %s", temp);
 	else
-	{
-		strcpy(command,datos);
-		strcat(command,temp);
-	}
+		snprintf(command, sizeof command, "%s %s", datos, temp);
 
 	g_spawn_command_line_sync(command, NULL, NULL, &exitstatus, NULL);
 
@@ -1188,8 +1169,10 @@ static void open_man_file(gchar *manfile)
 			{
 				utf8 = g_locale_to_utf8(buffer, -1, NULL, NULL, NULL);
 			}
-			if (utf8 != NULL)
-				strncpy(buffer,utf8,strlen(utf8));
+			if (utf8 != NULL){
+				strncpy(buffer,utf8, BUFFER_SIZE - 1);
+				buffer[BUFFER_SIZE - 1] = 0;
+			}
 			gtk_text_buffer_insert_at_cursor(tb, buffer ,bytes_read);
 		} 
 	  }
